'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var fs = require('fs');
var path = require('path');
var parse = require('@architect/parser');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var fs__default = /*#__PURE__*/_interopDefaultLegacy(fs);
var path__default = /*#__PURE__*/_interopDefaultLegacy(path);
var parse__default = /*#__PURE__*/_interopDefaultLegacy(parse);

/** @param {string} dir */
function mkdirp(dir) {
	try {
		fs__default['default'].mkdirSync(dir, { recursive: true });
	} catch (e) {
		if (e.code === 'EEXIST') return;
		throw e;
	}
}

/**
 * @param {string} from
 * @param {string} to
 * @param {(basename: string) => boolean} filter
 */
function copy(from, to, filter = () => true) {
	if (!fs__default['default'].existsSync(from)) return [];
	if (!filter(path__default['default'].basename(from))) return [];

	const files = [];
	const stats = fs__default['default'].statSync(from);

	if (stats.isDirectory()) {
		fs__default['default'].readdirSync(from).forEach((file) => {
			files.push(...copy(path__default['default'].join(from, file), path__default['default'].join(to, file)));
		});
	} else {
		mkdirp(path__default['default'].dirname(to));
		fs__default['default'].copyFileSync(from, to);
		files.push(to);
	}

	return files;
}

/** @param {string} file */
function parse_arc(file) {
	if (!fs.existsSync(file)) {
		throw new Error(`No ${file} found. See the documentation.`);
	}

	try {
		const text = fs.readFileSync(file).toString();
		const arc = parse__default['default'](text);

		return {
			static: arc.static[0][1]
		};
	} catch (e) {
		throw new Error(`Error parsing ${file}. Please consult the documentation for correct syntax.`);
	}
}

function index () {
	/** @type {import('@sveltejs/kit').Adapter} */
	const adapter = {
		name: '@sveltejs/adapter-begin',

		async adapt(builder) {
			builder.log.minor('Parsing app.arc file');
			const { static: static_mount_point } = parse_arc('app.arc');

			const lambda_directory = path.resolve(path.join('src', 'http', 'get-index'));
			const static_directory = path.resolve(static_mount_point);
			const server_directory = path.resolve(path.join('src', 'shared'));

			builder.log.minor('Writing client application...');
			builder.copy_static_files(static_directory);
			builder.copy_client_files(static_directory);

			builder.log.minor('Building lambda...');
			const local_lambda_dir = path.join(__dirname, 'files');
			copy(local_lambda_dir, lambda_directory);

			builder.log.minor('Writing server application...');
			builder.copy_server_files(server_directory);

			builder.log.minor('Prerendering static pages...');
			await builder.prerender({
				dest: static_directory
			});
		}
	};

	return adapter;
}

exports.default = index;
//# sourceMappingURL=index.cjs.map
